@@ -15,6 +15,7 @@ import configparser
 from loguru import logger
 import hashlib
 import platform
+import warnings
 
 # from Crypto.Cipher import AES
 # from binascii import b2a_hex
@@ -31,11 +32,23 @@ if system == "Darwin":
 configuration_file = "{}/apps/public/conf.ini".format(configuration_path_prefix)
 
 
-def getConfig():
+def getConfig(config_file=None):
+    warnings.warn("此方法已废弃，不推荐使用，请使用 get_config 替换。", DeprecationWarning)
+    return get_config(config_file)
+
+
+def execute_command(cmd):
+    warnings.warn("此方法已废弃，不推荐使用，请使用 command 替换。", DeprecationWarning)
+    return command(cmd)
+
+
+def get_config(config_file=None):
+    if config_file is None:
+        config_file = configuration_file
     print(configuration_file)
     import configparser
     config = configparser.ConfigParser()
-    config.read(configuration_file)
+    config.read(config_file)
     return config
 
 
@@ -79,8 +92,12 @@ def execute_command3(cmd):
     return status, output, lines
 
 
-# 执行shell命令,并返回结果
-def execute_command(cmd):
+def command(cmd):
+    """执行shell命令,并返回结果
+
+    :param cmd:
+    :return:
+    """
     major = sys.version_info[0]
     if major == 2:
         proc = subprocess.Popen([cmd, ], stdout=subprocess.PIPE, shell=True)
@@ -95,6 +112,22 @@ def timestamp(dt):
     return int(timetool.mktime(dt.timetuple()))
 
 
+def set_logger_level(level):
+    """设置loguru的日志级别
+
+    Args:
+        level: logger level,DEBUG,INFO,WARNING,ERROR....
+
+    Returns:
+        handler_id.
+    """
+    # 删去import logger之后自动产生的handler，不删除的话会出现重复输出的现象
+    logger.remove()
+    # 添加一个可以修改控制的handler
+    handler_id = logger.add(sys.stderr, level=level)
+    return handler_id
+
+
 def parseCommandArguments(args):
     arg_dict = {}
     for argument in args:
@@ -363,7 +396,7 @@ def eweixin_send_text(message, token=None, mobiles=[], is_at_all=False):
 
 def weixin_send_text(message, token=None, mobiles=[], is_at_all=False):
     if not token:
-        config = getConfig()
+        config = get_config()
         token = config.get("eweixin", "token")
     content = "{}[{}]\n{}".format(getLocalHostname(), getLocalIp(), message)
     data = json.dumps({"msgtype": "text", "text": {"content": content, "mentioned_mobile_list": mobiles}})
